==> img0ch-2.1.6.tar.bz2: img0ch/test/img0ch/3/Img0ch/FCGI/BootStrap.pm <==
#/*
# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
# *
# *  Licensed under the Apache License, Version 2.0 (the "License");
# *  you may not use this file except in compliance with the License.
# *  You may obtain a copy of the License at
# *
# *      http://www.apache.org/licenses/LICENSE-2.0
# *
# *  Unless required by applicable law or agreed to in writing, software
# *  distributed under the License is distributed on an "AS IS" BASIS,
# *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# *  See the License for the specific language governing permissions and
# *  limitations under the License.
# */
#
# $Id: BootStrap.pm 265 2007-02-20 15:16:17Z hikarin $
#

package Img0ch::FCGI::BootStrap;

use strict;
use CGI::Fast qw();
use File::Basename qw();
use Img0ch::Config qw();
use Img0ch::FCGI::Request qw();
use Img0ch::Maple qw();

sub import {
    my ( $iBootstrap, $app ) = @_;
    my $iConfig = Img0ch::Config->new();

    while (my $q = CGI::Fast->new()) {
        my $base = $ENV{SCRIPT_FILENAME} || $0;
        my $path = File::Basename::dirname($base);
        eval {
            $iConfig->load("${path}/img0ch-config.cgi");
            my $iKernel = Img0ch::Maple->new($iConfig);
            eval "use ${app} qw(); 1;" or die $@;
            $app->new( $iKernel, $q )->run();
        };
        if ( my $errstr = $@ ) {
            $errstr = Img0ch::Maple::escape_html_entities($errstr);
            $errstr =~ s/\n/<br>/gxms;
            $errstr =~ s/\s/&nbsp;/gxms;
            print 'Content-type: text/html', "\n\n", $errstr, "\n";
        }
    }
}

1;
__END__

==> img0ch-2.1.11.tar.bz2: img0ch/test/img0ch/3/Img0ch/FCGI/BootStrap.pm <==
#/*
# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
# *
# *  Licensed under the Apache License, Version 2.0 (the "License");
# *  you may not use this file except in compliance with the License.
# *  You may obtain a copy of the License at
# *
# *      http://www.apache.org/licenses/LICENSE-2.0
# *
# *  Unless required by applicable law or agreed to in writing, software
# *  distributed under the License is distributed on an "AS IS" BASIS,
# *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# *  See the License for the specific language governing permissions and
# *  limitations under the License.
# */
#
# $Id: BootStrap.pm 715 2007-05-29 13:14:36Z hikarin $
#

package Img0ch::FCGI::BootStrap;

use strict;
use CGI::Fast qw();
use File::Basename qw();
use Img0ch::Config qw();
use Img0ch::FCGI::Request qw();
use Img0ch::Maple qw();

my $img0ch_config_modified = 0;
sub import {
    my ( $iBootstrap, $app ) = @_;
    my $iConfig = Img0ch::Config->new();
    eval "use ${app} qw(); 1" or die $@, "\n";

    while ( my $q = CGI::Fast->new() ) {
        my $base     = $q->script_name() || $0;
        my $path     = File::Basename::dirname($base) . '/img0ch-config.cgi';
        my $modified = (stat($path))[9];
        if ( ( $img0ch_config_modified ||= $modified ) < $modified ) {
            print {*STDERR} '[', scalar(localtime(time())),
                '] restarted FastCGI application: ', $app, "\n";
            last;
        }
        eval {
            $iConfig->load($path);
            $app->new( Img0ch::Maple->new($iConfig), $q )->run();
        };
        if ( my $errstr = $@ ) {
            $errstr = Img0ch::Maple::escape_html_entities($errstr);
            $errstr =~ s/\n/<br>/gxms;
            $errstr =~ s/\s/&nbsp;/gxms;
            print 'Content-type: text/html', "\n\n", $errstr, "\n";
        }
    }
}

1;
__END__
